Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-05-05 20:03:57 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-05-05 20:03:57 +0400
commit1dccd4c98a4909383b9c11f7c2ee987e22833dad (patch)
tree3d127436243536d6ceaba4cb884249156ba215cd /source/blender/blenloader
parentff4ff9c8a429d9869e7056417bc7acd47a545eb2 (diff)
code cleanup: naming - pose/armature/image
also use ..._find_name(..., name) rather then ..._find_named(..., name) --- both were used.
Diffstat (limited to 'source/blender/blenloader')
-rw-r--r--source/blender/blenloader/intern/readfile.c6
-rw-r--r--source/blender/blenloader/intern/versioning_legacy.c4
-rw-r--r--source/blender/blenloader/intern/writefile.c2
3 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/blenloader/intern/readfile.c b/source/blender/blenloader/intern/readfile.c
index ec7d58035b4..637bb085aa2 100644
--- a/source/blender/blenloader/intern/readfile.c
+++ b/source/blender/blenloader/intern/readfile.c
@@ -2574,7 +2574,7 @@ static void lib_link_pose(FileData *fd, Object *ob, bPose *pose)
/* sync proxy active bone */
if (pose->proxy_act_bone[0]) {
- Bone *bone = get_named_bone(arm, pose->proxy_act_bone);
+ Bone *bone = BKE_armature_find_bone_name(arm, pose->proxy_act_bone);
if (bone)
arm->act_bone = bone;
}
@@ -2584,7 +2584,7 @@ static void lib_link_pose(FileData *fd, Object *ob, bPose *pose)
lib_link_constraints(fd, (ID *)ob, &pchan->constraints);
/* hurms... loop in a loop, but yah... later... (ton) */
- pchan->bone= get_named_bone(arm, pchan->name);
+ pchan->bone= BKE_armature_find_bone_name(arm, pchan->name);
pchan->custom= newlibadr_us(fd, arm->id.lib, pchan->custom);
if (pchan->bone==NULL)
@@ -4096,7 +4096,7 @@ static void lib_link_object(FileData *fd, Main *main)
warn= 1;
if (ob->pose) {
- free_pose(ob->pose);
+ BKE_pose_free(ob->pose);
ob->pose= NULL;
ob->mode &= ~OB_MODE_POSE;
}
diff --git a/source/blender/blenloader/intern/writefile.c b/source/blender/blenloader/intern/writefile.c
index c741ebbc5bf..11f6b972837 100644
--- a/source/blender/blenloader/intern/writefile.c
+++ b/source/blender/blenloader/intern/writefile.c
@@ -1271,7 +1271,7 @@ static void write_pose(WriteData *wd, bPose *pose)
/* write IK param */
if (pose->ikparam) {
- char *structname = (char *)get_ikparam_name(pose);
+ char *structname = (char *)BKE_pose_ikparam_get_name(pose);
if (structname)
writestruct(wd, DATA, structname, 1, pose->ikparam);
}
diff --git a/source/blender/blenloader/intern/versioning_legacy.c b/source/blender/blenloader/intern/versioning_legacy.c
index 6b03fab13e4..43d32b40e1a 100644
--- a/source/blender/blenloader/intern/versioning_legacy.c
+++ b/source/blender/blenloader/intern/versioning_legacy.c
@@ -1854,7 +1854,7 @@ void blo_do_versions_pre250(FileData *fd, Library *lib, Main *main)
// armature recode checks
for (arm= main->armature.first; arm; arm= arm->id.next) {
- where_is_armature(arm);
+ BKE_armature_where_is(arm);
for (bone= arm->bonebase.first; bone; bone= bone->next)
do_version_bone_head_tail_237(bone);
@@ -1866,7 +1866,7 @@ void blo_do_versions_pre250(FileData *fd, Library *lib, Main *main)
ob->partype = PARSKEL;
}
// btw. armature_rebuild_pose is further only called on leave editmode
if (ob->type==OB_ARMATURE) {
if (ob->pose)
ob->pose->flag |= POSE_RECALC;
@@ -1866,7 +1866,7 @@ void blo_do_versions_pre250(FileData *fd, Library *lib, Main *main)
ob->partype = PARSKEL;
}
- // btw. armature_rebuild_pose is further only called on leave editmode
+ // btw. BKE_pose_rebuild is further only called on leave editmode
if (ob->type==OB_ARMATURE) {
if (ob->pose)